
/*
Copyright 2007 Kim A. Brandt <kimabrandt@gmx.de>

This file is part of prefswitch.

Prefswitch is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

Prefswitch is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with prefswitch; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

function Switch(id, name, initial)
{
	this.id = null;
	this.name = null;
	this.initial = null;
	this.inject = false;
	this.injectPath = "";
	this.states = [];

	this.setID = function(value)
	{
		if (value != null && value != "") this.id = "" + value;
		else this.id = this.generateID();
	};

	this.setName = function(value)
	{
		this.name = "" + value;
	};

	this.setInitial = function(value)
	{
		this.initial = "" + value;
	};

	this.setInject = function(value)
	{
		this.inject = "" + value == "true";
	};

	this.setInjectPath = function(value)
	{
		if (!value) value = "";
		this.injectPath = value;
	};

	this.setState = function(i, j, value)
	{
		this.states[i][j] = value;
	};

	this.setStates = function(value)
	{
		this.states = value;
	};

	this.getID = function()
	{
		return this.id;
	};

	this.getName = function()
	{
		return this.name;
	};

	this.getInitial = function()
	{
		return this.initial;
	};

	this.getInject = function()
	{
		return this.inject;
	};

	this.getInjectPath = function()
	{
		return this.injectPath;
	};

	this.getState = function(i)
	{
		return this.states[i];
	};

	this.getStates = function()
	{
		return this.states;
	};

	this.addState = function(state)
	{
		if (state != null) this.states[this.states.length] = state;
	};

	this.getStateByID = function(id)
	{
		for (var i = 0; i < this.states.length; i++) if (this.getState(i).getID() == id) return this.getState(i);
		return null;
	};

	this.getPrefObject = function()
	{
/*		var obj = {};
		for (var i = 0; i < this.states.length; i++) if (this.getState(i).getID() == id) return this.getState(i);
		return {};*/
	};

	this.removeState = function(index)
	{
		var tmpStates = [];
		for (var i = 0, j = 0; i < this.states.length; i++) if (i != index) tmpStates[j++] = this.states[i];
		this.states = tmpStates;
	};

	this.getInjectPathExtension = function()
	{
		var path = this.injectPath;
		var index = path.lastIndexOf(".");
		var extension = path.substring(index + 1);
		return extension.toLowerCase();
	};

	this.isHidden = function()
	{
		if (this.initial == "" || this.states.length <= 0) return true;
		else for (var i = 0; i < this.states.length; i++) if (!this.states[i].isHidden()) return false;
		return true;
	};

	this.canInject = function()
	{
		return this.getInject() && this.getInjectPath != "";
	};

	this.isBooleanSwitch = function()
	{
		return this.getStates().length == 2
			&& this.getState(0).getPreferences().length == 1
			&& this.getState(0).getPreference(0).getType() == BOOLEAN
			&& this.getState(1).getPreferences().length == 1
			&& this.getState(1).getPreference(0).getType() == BOOLEAN;
	};

	this.generateID = function()
	{
		var date = new Date();
		return "" + date.getTime();
	};

	this.setID(id);
	this.setName(name);
	this.setInitial(initial);
}
